"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const log_1 = require("../common/log");
const util_1 = require("../common/util");
const child_process_1 = require("child_process");
exports.command = "test";
exports.desc = "单元测试";
exports.builder = (yargs) => {
    return yargs
        .option("p", {
        alias: "path",
        describe: "测试的目录",
        default: ".",
        type: "string"
    })
        .usage("Usage: $0 test -p .");
};
exports.handler = (yargs) => {
    log_1.printMessage("单元测试开始...");
    let projectPath = path.resolve(yargs.p) || process.cwd();
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let mocha = util_1.getCreateProjectDependencies(projectPath, path.join("mocha", "bin", "mocha"));
    let childProcess = child_process_1.spawn(nyc, [mocha, "-t", "5000"], {
        cwd: projectPath,
        stdio: [process.stdin, process.stdout, process.stderr]
    });
    childProcess.on("exit", code => {
        log_1.printMessage("单元测试结束");
        if (code != 0) {
            process.exit(code);
        }
    });
    child_process_1.exec(`"${nyc}" report --reporter=text-lcov | coveralls`, { encoding: "utf-8" }, (err, stdout, stderr) => {
        if (err) {
            process.exit(1);
        }
        else {
            log_1.printMessage("覆盖率完成" + stdout);
        }
    });
};
//# sourceMappingURL=test.js.map